# CRAFTED - An exploratory database of simulated adsorption isotherms of metal-organic frameworks

## Overview

The files in this repository compose the **C**harge-dependent, **R**eproducible, **A**ccessible, **F**orcefield-dependent, and **T**emperature-dependent **E**xploratory **D**atabase (**CRAFTED**) of adsorption isotherms. This dataset contains the simulation of CO2 and N2 adsorption isotherms on 690 metal-organic frameworks taken from the CoRE MOF 2014 database. The simulations were performed with two force fields (UFF and DREIDING), six partial charge schemes (no charges, Qeq, EQeq, DDEC, MPNN, and PACMOF), and three temperatures (273, 298, 323 K).

### Contents

- `CIF_FILES/` contains 6 folders (NEUTRAL, DDEC, EQeq, Qeq, MPNN, and PACMOF), each one with 690 CIF files;
- `FORCEFIELDS/` contains 2 folders (UFF and DREIDING) with the definition of the forcefields;
- `INPUT_FILES/` contains 49,680 input files for the GCMC simulations;
- `ISOTHERM_FILES/` contains 49,680 adsorption isotherms resulting from the GCMC simulation;
- `ENTHALPY_FILES/` contains 49,680 enthalpies of adsorption from the isotherms;
- `RAC_DBSCAN/` contains the RAC and geometrical descriptors to perform the t-NSE + DBSCAN analysis;

### Licenses

The CIF files in the `DDEC` folder were downloaded from [CoRE MOF 2014](https://doi.org/10.5281/zenodo.3986573) and are licensed under the terms of the Creative Commons Attribution 4.0 International license ([`CC-BY-4.0`](https://creativecommons.org/licenses/by/4.0/legalcode)).

> Dalar Nazarian, Jeffrey S. Camp, & David S. Sholl. (2016). Computation-Ready Experimental Metal-Organic Framework (CoRE MOF) 2014 DDEC Database [Data set]. Zenodo. <https://doi.org/10.5281/zenodo.3986573>

The `CO2.def` and `N2.def` forcefield files were downloaded from [RASPA](https://github.com/iRASPA/RASPA2/tree/master/molecules/ExampleDefinitions) and are licensed under the terms of the [MIT](https://github.com/iRASPA/RASPA2/blob/master/COPYING) license.

> RASPA: a molecular-dynamics, monte-carlo and optimization code for nanoporous materials.
> Copyright (C) 2006-2019 David Dubbeldam, Sofia Calero, Thijs Vlugt, Donald E. Ellis, and Randall Q. Snurr.

The CIF files in the `PACMOF`, `MPNN`, `Qeq`, `EQeq` and `NEUTRAL` folders were derived from those in the `DDEC` folder and are licensed under the terms of the Creative Commons Attribution 4.0 International license ([`CC-BY-4.0`](https://creativecommons.org/licenses/by/4.0/legalcode)).

All remaining files are licensed under the terms of the [`CDLA-Sharing-1.0`](https://cdla.dev/sharing-1-0/) license.

### Software requirements

In order to create a Python environment capable of running the Jupyter notebooks, please install [`conda`](https://docs.conda.io/en/latest/miniconda.html) and execute

```Shell
conda env create --file environment.yml
```

### Usage instructions

Execute the command below to run JupyterLab in the appropriate Python environment.

```Shell
conda run --name crafted jupyter-lab
```
